@@ -134,6 +134,8 @@ def ifIsDeadDoNothing(func):
 
 
 def getPerfFile(perf_dir):
+    """ return the perf file for reporting time"""
+
     if not os.path.exists(perf_dir):
         raise Exception('%s doesnt exists' % perf_dir)
     else:
@@ -182,6 +184,9 @@ class Worker(threading.Thread):
                 break # reached end of queue
             (func,args)  = (elt[0],elt[1:])
             func(*args)
+            ## signals to queue job is done
+            ## not for python24
+            ## self.__queue.task_done()
             
 def queue_tasks(tasks):
     ##be sure that task is an list
@@ -191,6 +196,8 @@ def queue_tasks(tasks):
     for task in tasks:
         queue.put(task)
     [queue.put(None) for x in xrange(len(tasks))]
+    #wait on the queue until everything has been processed  
+    #queue.join()
     while threading.activeCount() != 1:
          time.sleep(.1)
     return
@@ -326,7 +333,8 @@ class Service(object):
                                   stderr = subprocess.STDOUT)
         except:
             ## there is a bug for python2.4 in subprocess call
-            ## we can check ping
+            ## if we can check ping we return true
+            ## http://bugs.python.org/issue1467770
             ret = 0
             return True
             
@@ -733,16 +741,13 @@ class Pound(TCPServer):
             ## restart the last client
             restart(zeoclients[-1])
         
-
         def queue_check():
-            for client in zeoclients:
+             for client in zeoclients:
                 yield (check, client)
 
         queue_tasks(queue_check())
         
         ## feed cache
-        
-        
         good = [client for client in zeoclients if client.status == True]
 
         def queue_feedcache():
@@ -964,19 +969,16 @@ class Cluster(object):
         else:
             #services_to_check = self.zeoclients
             services_to_check = self.services
-        #--- checking frontends ---
-
-        ## must be an adapter of an client 
+        ##--- checking frontends ---
+        ## warning - I dont know but zca dont like that with thread
         def check(service):
             for adapter in component.subscribers([service],
                                                  interfaces.IChecker):
                 adapter.check()
-
-        def queue():
-            for client in services_to_check:
-                yield (check, client)
+        ## sync check        
+        for client in services_to_check:
+            check(client)
         
-        queue_tasks(queue())
 
     def repair(self, services = None, url = '', **args):
         """
